@@ -71,7 +71,7 @@ disperse <- function(xy, disp=.1, area.size=10){
 simOutbreak <- function(R0, infec.curve, n.hosts=200, duration=50,
                         seq.length=1e4, mu.transi=1e-4, mu.transv=mu.transi/2,
                         rate.import.case=0.01, diverg.import=10, group.freq=1,
-                        spatial=TRUE, disp=0.1, area.size=10, reach=1,
+                        spatial=FALSE, disp=0.1, area.size=10, reach=1,
                         plot=spatial){
 
     ## HANDLE ARGUMENTS ##
@@ -555,16 +555,6 @@ plot.simOutbreak <- function(x, y=NULL, edge.col="black", col.edge.by="dist", ve
 
 
 
-
-
-
-
-
-
-
-
-
-
 ## #####################
 ## ## seqTrack.simOutbreak
 ## #####################
@@ -661,16 +651,3 @@ plot.simOutbreak <- function(x, y=NULL, edge.col="black", col.edge.by="dist", ve
 ##     return(res)
 ## } # end sample.simOutbreak
 
-
-
-
-
-
-
-
-
-
-
-
-
-
