@@ -31,6 +31,7 @@
      list_dnaseq * dna; /* sequences */
      vec_int * idxCasesInDna; /* index of DNA sequence  in 'dna' for each case; -1 if DNA missing */
      int timespan; /* timespan of the data */
+     vec_int * locations; /* integer indicating locations of cases - used in stratified dispersal model */
  } data;
 
 
@@ -61,10 +62,11 @@ typedef struct{
     double spa_param1_prior, spa_param2_prior; /* parameters of priors of spatial param */
     int kappa_temp; /* used to store temporary kappa for genetic LL */
     double outlier_threshold; /* threshold used in outlier detection */
-    int mut_model; /* genetic mut_model: 0=1 mutation rate; 1=mutation1/mutation2 */
-    int spa_model; /* spatial model: 0=no, 1=model1, 2=model2, ...*/
-    /* double phi; /\* proba of external case *\/ */
-    /* double phi_param1, phi_param2; /\* parameters of the Beta prior for phi *\/ */
+    int mut_model; /* genetic model: 0=nothing; 1=1 mutation rate; 2=transi/transver */
+    int spa_model; /* spatial model: 0=no, 1=exponential, 2=stratified exponential, ...*/
+    int import_method; /* import method: 0=none; 1=based on genetic LL; 2=based on full LL */
+    double phi; /* proba of nosocomial infection */
+    double phi_param1, phi_param2; /* parameters of the Beta prior for phi */
 } param;
 
 
@@ -75,9 +77,9 @@ typedef struct{
     int n_accept_mu1, n_reject_mu1; /* accept/reject for mu1 */
     int n_accept_gamma, n_reject_gamma; /* accept/reject for gamma */
     int n_accept_pi, n_reject_pi; /* accept/reject for pi */
+    int n_accept_phi, n_reject_phi; /* accept/reject for phi */
     int n_accept_spa1, n_reject_spa1; /* accept/reject for spa1 */
     int n_accept_spa2, n_reject_spa2; /* accept/reject for spa2 */
-    /* int n_accept_phi, n_reject_phi; /\* accept/reject for phi *\/ */
     int n_accept_Tinf, n_reject_Tinf; /* accept/reject for Tinf */
     int n_accept_alpha, n_reject_alpha; /* accept/reject for alpha */
     int n_accept_kappa, n_reject_kappa; /* accept/reject for kappa */
@@ -86,8 +88,8 @@ typedef struct{
     double sigma_gamma; /* sigma for normal proposal for gamma */
     double lambda_Tinf; /* lambda for Poisson movements of Tinf */
     double sigma_pi; /* sigma for normal proposal for pi */
+    double sigma_phi; /* sigma for normal proposal for phi */
     double sigma_spa1, sigma_spa2; /* sigma for proposal for spa1 and spa2 */
-    /* double sigma_phi; /\* sigma for normal proposal for phi *\/ */
     vec_int *idx_move_Tinf; /* vector of length n_move_Tinf giving indices of Tinf_i to move */
     vec_int *idx_move_alpha; /* vector of length n_move_alpha giving indices of alpha_i to move */
     vec_int *idx_move_kappa; /* vector of length n_move_kappa giving indices of kappa_i to move */
@@ -96,9 +98,9 @@ typedef struct{
     vec_double *candid_ances_proba; /* vector of proba for candidate ancestors, used to move alpha_i */
     /* double Pmove_alpha_old, Pmove_alpha_new; /\* used for accept ratio when moving alpha_i *\/ */
     int n_like_zero; /* number of times likelihood was zero */
-    bool tune_all, tune_mu1, tune_gamma, tune_pi, tune_spa1, tune_spa2; /* logical indicating whether these proposals should be tuned */
+    bool tune_any, tune_mu1, tune_gamma, tune_pi, tune_phi, tune_spa1, tune_spa2; /* logical indicating whether these proposals should be tuned */
     int step_notune; /* step at which all tuning stopped */
-    bool move_mut, move_Tinf, move_pi, move_spa1, move_spa2; /* logical indicating what parameter should be moved */
+    bool move_mut, move_Tinf, move_pi, move_phi, move_spa; /* logical indicating what parameter should be moved */
     vec_double * move_alpha; /* vector indicating which alpha_i to move (1.0) or not (0.0) */
     vec_double * move_kappa; /* vector indicating which kappa_i to move (1.0) or not (0.0) */
     int burnin, find_import_at; /* chains between 'burnin' and 'find_import_at' are used to find imported cases */
@@ -130,7 +132,7 @@ void free_data(data *in);
 
 void print_data(data *in);
 
-data * Rinput2data(unsigned char * DNAbinInput, int *Tcollec, int *n,int *nSeq, int *length, int *idxCasesInDna);
+data * Rinput2data(unsigned char * DNAbinInput, int *Tcollec, int *n,int *nSeq, int *length, int *idxCasesInDna, int *locations);
 
 
 
